==> humhub-1.11.0-beta.2.tar.gz: humhub-1.11.0-beta.2/protected/humhub/modules/user/messages/es/account.php <==
<?php

return [
    '<strong>Account</strong> settings' => 'Ajustes de <strong>cuenta</strong>',
    '<strong>Confirm</strong></strong> your new email address' => '<strong>Confirma</strong> tu nueva dirección de correo electrónico',
    '<strong>Permissions</strong>' => '<strong> Permisos </strong>',
    '<strong>User</strong> settings' => 'Ajustes del <strong>usuario</strong>',
    '<strong>Your</strong> profile' => '<strong>Tu</strong> perfil',
    'All your personal data will be irrevocably deleted.' => 'Todos tus datos personales se borrarán irreversiblemente.',
    'Are you sure that you want to delete your account?' => '¿Seguro que quieres borrar tu cuenta?',
    'Blocked users' => 'Usuarios bloqueados',
    'Changing the username can make some links unusable, for example old links to the profile.' => 'Cambiar el nombre de usuario puede hacer que algunos enlaces queden rotos, como por ejemplo enlaces antiguos que apunten al perfil.',
    'Confirm' => 'Confirmar',
    'Current password' => 'Contraseña actual',
    'Delete account' => 'Borrar cuenta',
    'Do you really want to delete your icon image?' => '¿De verdad quieres borrar tu icono?',
    'Do you really want to delete your logo image?' => '¿Seguro que quieres eliminar el logo?',
    'E-Mail' => 'Correo electrónico',
    'E-Mail change' => 'Cambiar correo electrónico',
    'Enter your password to continue' => 'Introduce tu clave para continuar',
    'Hello' => 'Hola',
    'Here you can edit your general profile data, which is visible in the about page of your profile.' => 'Aquí puede editar los datos de su perfil general, que es visible en tu página de Acerca de en tu perfil.',
    'Hide introduction tour panel on dashboard' => 'Ocultar el panel paseo de introducción en el dashboard.',
    'Invalid link! Please make sure that you entered the entire url.' => '¡Enlace no válido! Por favor, asegurate de que has introducir la url completa.',
    'Language' => 'Idioma',
    'Modules' => 'Módulos',
    'New E-Mail address' => 'Nueva dirección de correo electrónico',
    'New User name' => 'Nuevo nombre de usuario',
    'Not registered users' => 'Usuarios no registrados',
    'Notifications' => 'Notificaciones',
    'Other users' => 'Otros usuarios',
    'Password Recovery' => 'Recuperar contraseña',
    'Permissions' => 'Permisos',
    'Profile' => 'Perfil',
    'Profile visibility' => 'Visibilidad del perfil',
    'Registered users only' => 'Sólo usuarios registrados',
    'Save' => 'Guardar',
    'Save profile' => 'Guardar perfil',
    'Settings' => 'Ajustes',
    'Tags' => 'Etiquetas',
    'The entered e-mail address is already in use by another user.' => 'El correo electrónico introducido ya está en uso por otro usuario.',
    'These settings allow you to determine which permissions you want to grant visitors of your own individual profile. Each user can freely adjust the settings for his or her own profile.' => 'Esta configuración le permite determinar qué permisos desea otorgar a los visitantes de su propio perfil individual. Cada usuario puede ajustar libremente la configuración de su propio perfil.',
    'TimeZone' => 'Zona horaria',
    'Username has been changed' => 'Se ha cambiado el nombre del usuario',
    'Users' => 'Usuarios',
    'Visible for all (also unregistered users)' => 'Visible para todos (también usuarios no registrados)',
    'We´ve just sent an confirmation e-mail to your new address. <br /> Please follow the instructions inside.' => 'Acabamos de enviar un correo electrónico de confirmación a tu nueva dirección. <br /> Por favor, sigue las instrucciones que contiene.',
    'You are currently the owner of following spaces:' => 'Actualmente eres el propietario de los siguientes espacios:',
    'You have requested to change your e-mail address.<br>Your new e-mail address is {newemail}.<br><br>To confirm your new e-mail address please click on the button below.' => 'Has solicitado cambiar tu dirección de correo electrónico.<br />Tu nueva dirección de correo electrónico es {newemail}.<br /><br />Para confirmar tu nueva dirección de correo electrónico, por favor, haz clic en el botón de abajo.',
    'You have successfully changed your username.<br>Your new username is {newUsername}.' => 'Se ha cambiado correctamente tu nombre de usuario.<br />Tu nuevo nombre de usuario es {newUsername}.',
    'You must transfer ownership or delete these spaces before you can delete your account.' => 'Antes de poder borrar tu cuenta tienes que borrar o transferir la propiedad de los siguientes espacios:',
    'Your account cannot be deleted!' => '¡Tu cuenta no puede ser borrada!',
    'Your current E-mail address is <b>{email}</b>. You can change your current E-mail address here.' => 'Tu dirección de correo actual es <b>{email}</b>. Puedes cambiar tu dirección de correo aquí.',
    'Your current password can be changed here.' => 'Puede cambiar aquí su clave actual.',
    'Your current username is <b>{username}</b>. You can change your current username here.' => 'Su nombre de usuario actual es <b>{username}</b>. Puede cambiar su nombre de usuario actual aquí.',
    'Your e-mail address has been successfully changed to {email}.' => 'Tu dirección de correo electrónico ha sido cambiada con éxito a {email}',
    'Your friends' => 'Tus amigos',
    'Your password has been successfully changed!' => '¡Tu contraseña ha sido cambiada con éxito!',
    'Your username has been changed' => 'Se ha cambiado tu nombre de usuario',
    'Your username has been successfully changed. <br> We´ve just sent an e-mail to you with new information.' => 'Se ha cambiado correctamente tu nombre de usuario.<br /> Te acabamos de enviar un mensaje de correo electrónico con la nueva información.',
    '{attribute} "{value}" was not found!' => '¡{attribute} "{value}" no ha sido encontrado!',
    'You cannot use this username.' => '',
];

==> humhub-1.17.0-beta.2.tar.gz: humhub-1.17.0-beta.2/protected/humhub/modules/user/messages/es/account.php <==
<?php

return [
    '<strong>Account</strong> Settings' => 'Configuración de la <strong>cuenta</strong>',
    '<strong>Confirm</strong></strong> your new email address' => '<strong>Confirma</strong> tu nueva dirección de correo electrónico',
    '<strong>Permissions</strong>' => '<strong> Permisos </strong>',
    '<strong>Your</strong> Account' => '<strong>Su</strong> Cuenta',
    '<strong>Your</strong> profile' => '<strong>Tu</strong> perfil',
    'Add tags to your profile describing you and highlighting your skills and interests. Your tags will be displayed in your profile and in the \'People\' directory.' => 'Añade a tu perfil etiquetas que te describan y que muestren tus habilidades e intereses. Tus etiquetas se mostrarán en tu perfil y en el directorio “Personas”.',
    'All your personal data will be irrevocably deleted.' => 'Todos tus datos personales se borrarán irreversiblemente.',
    'Are you sure that you want to delete your account?' => '¿Seguro que quieres borrar tu cuenta?',
    'Blocked users' => 'Usuarios bloqueados',
    'Changing the username can make some links unusable, for example old links to the profile.' => 'Cambiar el nombre de usuario puede hacer que algunos enlaces queden rotos, como por ejemplo enlaces antiguos que apunten al perfil.',
    'Confirm' => 'Confirmar',
    'Current password' => 'Contraseña actual',
    'Define basic settings for your profile. You can add tags that fit you, choose the language and your time zone and block impolite users.' => 'Define los parámetros básicos de tu perfil. Puedes añadir etiquetas que te definan, tu idioma y tu zona horaria, y también puedes bloquear a usuarios desagradables.',
    'Delete account' => 'Borrar cuenta',
    'Do you really want to delete your icon image?' => '¿De verdad quieres borrar tu icono?',
    'Do you really want to delete your logo image?' => '¿Seguro que quieres eliminar el logo?',
    'E-Mail' => 'Correo electrónico',
    'E-Mail change' => 'Cambiar correo electrónico',
    'Enter your password to continue' => 'Introduce tu clave para continuar',
    'General' => 'General',
    'Hello' => 'Hola',
    'Here you can edit your general profile data, which is visible in the about page of your profile.' => 'Aquí puede editar los datos de su perfil general, que es visible en tu página de Acerca de en tu perfil.',
    'Hide introduction tour panel on dashboard' => 'Ocultar el panel paseo de introducción en el dashboard.',
    'Hide my online status' => 'Ocultar mi estado online',
    'Invalid link! Please make sure that you entered the entire url.' => '¡Enlace no válido! Por favor, asegurate de que has introducir la url completa.',
    'Language' => 'Idioma',
    'Markdown Editor Mode' => 'Modo de edición Markdown',
    'Modules' => 'Módulos',
    'New E-Mail address' => 'Nueva dirección de correo electrónico',
    'New User name' => 'Nuevo nombre de usuario',
    'Not registered users' => 'Usuarios no registrados',
    'Notifications' => 'Notificaciones',
    'Other users' => 'Otros usuarios',
    'Password Recovery' => 'Recuperar contraseña',
    'Permissions' => 'Permisos',
    'Plain' => 'Plano',
    'Profile' => 'Perfil',
    'Profile Tags' => 'Etiquetas del perfil',
    'Profile visibility' => 'Visibilidad del perfil',
    'Registered users only' => 'Sólo usuarios registrados',
    'Rich Text' => 'Texto rico',
    'Save' => 'Guardar',
    'Save profile' => 'Guardar perfil',
    'The entered e-mail address is already in use by another user.' => 'El correo electrónico introducido ya está en uso por otro usuario.',
    'These settings allow you to determine which permissions you want to grant visitors of your own individual profile. Each user can freely adjust the settings for his or her own profile.' => 'Esta configuración le permite determinar qué permisos desea otorgar a los visitantes de su propio perfil individual. Cada usuario puede ajustar libremente la configuración de su propio perfil.',
    'TimeZone' => 'Zona horaria',
    'Username has been changed' => 'Se ha cambiado el nombre del usuario',
    'Users' => 'Usuarios',
    'Visible for all (also unregistered users)' => 'Visible para todos (también usuarios no registrados)',
    'We´ve just sent an confirmation e-mail to your new address. <br /> Please follow the instructions inside.' => 'Acabamos de enviar un correo electrónico de confirmación a tu nueva dirección. <br /> Por favor, sigue las instrucciones que contiene.',
    'You are currently the owner of following spaces:' => 'Actualmente eres el propietario de los siguientes espacios:',
    'You cannot use this username.' => 'No puedes utilizar ese nombre de usuario.',
    'You have requested to change your e-mail address.<br>Your new e-mail address is {newemail}.<br><br>To confirm your new e-mail address please click on the button below.' => 'Has solicitado cambiar tu dirección de correo electrónico.<br />Tu nueva dirección de correo electrónico es {newemail}.<br /><br />Para confirmar tu nueva dirección de correo electrónico, por favor, haz clic en el botón de abajo.',
    'You have successfully changed your username.<br>Your new username is {newUsername}.' => 'Se ha cambiado correctamente tu nombre de usuario.<br />Tu nuevo nombre de usuario es {newUsername}.',
    'You must transfer ownership or delete these spaces before you can delete your account.' => 'Antes de poder borrar tu cuenta tienes que borrar o transferir la propiedad de los siguientes espacios:',
    'Your account cannot be deleted!' => '¡Tu cuenta no puede ser borrada!',
    'Your current E-mail address is <b>{email}</b>. You can change your current E-mail address here.' => 'Tu dirección de correo actual es <b>{email}</b>. Puedes cambiar tu dirección de correo aquí.',
    'Your current password can be changed here.' => 'Puede cambiar aquí su clave actual.',
    'Your current username is <b>{username}</b>. You can change your current username here.' => 'Su nombre de usuario actual es <b>{username}</b>. Puede cambiar su nombre de usuario actual aquí.',
    'Your e-mail address has been successfully changed to {email}.' => 'Tu dirección de correo electrónico ha sido cambiada con éxito a {email}',
    'Your friends' => 'Tus amigos',
    'Your password has been successfully changed!' => '¡Tu contraseña ha sido cambiada con éxito!',
    'Your username has been changed' => 'Se ha cambiado tu nombre de usuario',
    'Your username has been successfully changed. <br> We´ve just sent an e-mail to you with new information.' => 'Se ha cambiado correctamente tu nombre de usuario.<br /> Te acabamos de enviar un mensaje de correo electrónico con la nueva información.',
    'Password recovery can only be initiated once every 10 minutes.' => '',
    'Password recovery disabled. Please contact your system administrator.' => '',
];
